DataTables example - Nested object data (arrays)

# DataTables example Nested object data (arrays)

The information read from an Ajax data source can be arbitrarily complex, but still be displayed by DataTables through the `columns.dataDT` option, which is particularly useful for working with JSON feeds in an already defined format.

The `columns.dataDT` option has the ability to read information not only from objects, but also from arrays using the same dotted object syntax as for objects. In addition to this, when working with an array data source `columns.dataDT` can process the data to combine and display the data in simple forms (more complex forms can be defined by using `columns.dataDT` as a function).

This example shows two different aspects of using `columns.dataDT` to read arrays:

- The Name column is sourced from an array of two elements (first and last name), which are automatically concatenated together. This is done by using array bracket syntax, with the characters between the brackets being used as the glue between elements (e.g. `name[, ]`).
- The Position, Start date and Salary columns are read directly from array elements using dotted object notation (e.g. `hr.0`). Note that the order in which the data can be used in the columns does not have to match the order in which it is defined in the data source. The structure of the row's data source in this example is:

    {
    	"name": [
    		"Nixon",
    		"Tiger"
    	],
    	"hr": [
    		"System Architect",
    		"$3,120",
    		"2011/04/25"
    	],
    	"office": "Edinburgh",
    	"extn": "5421"
    }

Name | Position | Office | Extn. | Start date | Salary
--- | --- | --- | --- | --- | ---
Name | Position | Office | Extn. | Start date | Salary

- Javascript
- HTML
- CSS
- Ajax
- Server-side script

The Javascript shown below is used to initialise the table shown in this example:

`$(document).ready(function() { $('#example').dataTable( { "ajax": "data/objects_subarrays.txt", "columns": [ { "data": "name[, ]" }, { "data": "hr.0" }, { "data": "office" }, { "data": "extn" }, { "data": "hr.2" }, { "data": "hr.1" } ] } ); } );`

In addition to the above code, the following Javascript library files are loaded for use in this example:

- ../../media/js/jquery.js
- ../../media/js/jquery.dataTables.js

The HTML shown below is the raw HTML table element, before it has been enhanced by DataTables:

This example uses a little bit of additional CSS beyond what is loaded from the library files (below), in order to correctly display the table. The additional CSS used is shown below:

``

The following CSS library files are loaded for use in this example to provide the styling of the table:

- ../../media/css/jquery.dataTables.css

This table loads data by Ajax. The latest data that has been loaded is shown below. This data will update automatically as any additional data is loaded.

The script used to perform the server-side processing for this table is shown below. Please note that this is just an example script using PHP. Server-side processing scripts can be written in any language, using the protocol described in the DataTables documentation.